@@ -1,24 +1,23 @@
 import warnings
-
-warnings.simplefilter(action="ignore", category=FutureWarning)
-
 import plac
 import spacy
 import srsly
 
 from wasabi import msg
 
-from spacy_crfsuite.crf_extractor import CRFExtractor, prepare_example
-from spacy_crfsuite.dense_features import DenseFeatures
+from spacy_crfsuite.crf_extractor import CRFExtractor
 from spacy_crfsuite.tokenizer import SpacyTokenizer
+from spacy_crfsuite.train import gold_example_to_crf_tokens
 from spacy_crfsuite.utils import read_file
 
+warnings.simplefilter(action="ignore", category=FutureWarning)
+
 
 @plac.annotations(
     in_file=("Path to input file (either .json, .md or .conll)", "positional", None, str),
     model_file=("Path to model file", "option", "m", str),
     config_file=("Path to config file (.json format)", "option", "c", str),
-    spacy_model=("Name of spaCy model to use", "positional", None, str),
+    spacy_model=("Name of spaCy model to use", "option", "lm", str),
 )
 def main(in_file, model_file=None, config_file=None, spacy_model=None):
     """Train CRF entity tagger."""
@@ -45,18 +44,10 @@ def main(in_file, model_file=None, config_file=None, spacy_model=None):
         msg.info(f"Using spaCy blank: 'en'")
 
     tokenizer = SpacyTokenizer(nlp=nlp)
-
-    if crf_extractor.use_dense_features():
-        dense_features = DenseFeatures(nlp)
-    else:
-        dense_features = None
-
+    use_dense_features = crf_extractor.use_dense_features()
     dev_crf_examples = [
-        prepare_example(
-            ex,
-            crf_extractor=crf_extractor,
-            tokenizer=tokenizer,
-            dense_features=dense_features,
+        gold_example_to_crf_tokens(
+            ex, tokenizer=tokenizer, use_dense_features=use_dense_features
         )
         for ex in dev_examples
     ]
